use super::*;

impl TailwindBuilder {
    ///
    #[inline]
    pub fn clear(&mut self) {
        self.objects.clear();
        self.bundles.clear();
    }
}
